==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDevice.md <==
# AwsIoTAlexaEnabledDevice


```text
aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDevice
```

```text
include('aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDevice')
```



| Illustration | AwsIoTAlexaEnabledDevice | AwsIoTAlexaEnabledDeviceCard | AwsIoTAlexaEnabledDeviceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDevice.png) | ![illustration for AwsIoTAlexaEnabledDevice](../../../aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDevice.Local.png) | ![illustration for AwsIoTAlexaEnabledDeviceCard](../../../aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDeviceCard.Local.png) | ![illustration for AwsIoTAlexaEnabledDeviceGroup](../../../aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDeviceGroup.Local.png) |




## AwsIoTAlexaEnabledDevice

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaEnabledDevice
include('aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDevice')

' renders the element
AwsIoTAlexaEnabledDevice('AwsIoTAlexaEnabledDevice', 'Aws Io T Alexa Enabled Device', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaEnabledDevice
include('aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDevice')

' renders the element
AwsIoTAlexaEnabledDevice('AwsIoTAlexaEnabledDevice', 'Aws Io T Alexa Enabled Device', 'an optional tech label')
@enduml
```

## AwsIoTAlexaEnabledDeviceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaEnabledDeviceCard
include('aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDevice')

' renders the element
AwsIoTAlexaEnabledDeviceCard('AwsIoTAlexaEnabledDeviceCard', 'Aws Io T Alexa Enabled Device Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaEnabledDeviceCard
include('aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDevice')

' renders the element
AwsIoTAlexaEnabledDeviceCard('AwsIoTAlexaEnabledDeviceCard', 'Aws Io T Alexa Enabled Device Card', 'an optional description')
@enduml
```

## AwsIoTAlexaEnabledDeviceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaEnabledDeviceGroup
include('aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDevice')

' renders the element
AwsIoTAlexaEnabledDeviceGroup('AwsIoTAlexaEnabledDeviceGroup', 'Aws Io T Alexa Enabled Device Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaEnabledDeviceGroup
include('aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDevice')

' renders the element
AwsIoTAlexaEnabledDeviceGroup('AwsIoTAlexaEnabledDeviceGroup', 'Aws Io T Alexa Enabled Device Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDevice.md <==
# AwsIoTAlexaEnabledDevice


```text
aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDevice
```

```text
include('aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDevice')
```



| Illustration | AwsIoTAlexaEnabledDevice | AwsIoTAlexaEnabledDeviceCard | AwsIoTAlexaEnabledDeviceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDevice.png) | ![illustration for AwsIoTAlexaEnabledDevice](../../../aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDevice.Local.png) | ![illustration for AwsIoTAlexaEnabledDeviceCard](../../../aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDeviceCard.Local.png) | ![illustration for AwsIoTAlexaEnabledDeviceGroup](../../../aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDeviceGroup.Local.png) |




## AwsIoTAlexaEnabledDevice

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaEnabledDevice
include('aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDevice')

' renders the element
AwsIoTAlexaEnabledDevice('AwsIoTAlexaEnabledDevice', 'Aws Io T Alexa Enabled Device', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaEnabledDevice
include('aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDevice')

' renders the element
AwsIoTAlexaEnabledDevice('AwsIoTAlexaEnabledDevice', 'Aws Io T Alexa Enabled Device', 'an optional tech label')
@enduml
```

## AwsIoTAlexaEnabledDeviceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaEnabledDeviceCard
include('aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDevice')

' renders the element
AwsIoTAlexaEnabledDeviceCard('AwsIoTAlexaEnabledDeviceCard', 'Aws Io T Alexa Enabled Device Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaEnabledDeviceCard
include('aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDevice')

' renders the element
AwsIoTAlexaEnabledDeviceCard('AwsIoTAlexaEnabledDeviceCard', 'Aws Io T Alexa Enabled Device Card', 'an optional description')
@enduml
```

## AwsIoTAlexaEnabledDeviceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaEnabledDeviceGroup
include('aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDevice')

' renders the element
AwsIoTAlexaEnabledDeviceGroup('AwsIoTAlexaEnabledDeviceGroup', 'Aws Io T Alexa Enabled Device Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaEnabledDeviceGroup
include('aws-20210730/Resource/LoT/AwsIoTAlexaEnabledDevice')

' renders the element
AwsIoTAlexaEnabledDeviceGroup('AwsIoTAlexaEnabledDeviceGroup', 'Aws Io T Alexa Enabled Device Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
